# `geoarrow.rust.core`

Root for `geoarrow.rust.core` API docs.

All functionality described within this directory are part of the `geoarrow.rust.core` submodule. To use, install the `geoarrow-rust-core` PyPI package:

```
pip install geoarrow-rust-core
```
